@@ -2,15 +2,15 @@
 dsml - generate and parse DSMLv1 data
 (see http://www.oasis-open.org/committees/dsml/)
 
-See http://www.python-ldap.org/ for details.
+See https://www.python-ldap.org/ for details.
 
-$Id: dsml.py,v 1.56 2017/04/28 20:03:51 stroeder Exp $
+$Id: dsml.py,v 1.61 2017/09/04 14:56:11 stroeder Exp $
 
 Python compability note:
 Tested with Python 2.0+.
 """
 
-__version__ = '2.4.39'
+__version__ = '2.4.43'
 
 import string,base64
 
