@@ -1,14 +1,14 @@
 """
 ldap - base module
 
-See http://www.python-ldap.org/ for details.
+See https://www.python-ldap.org/ for details.
 
-$Id: __init__.py,v 1.117 2017/04/28 20:03:52 stroeder Exp $
+$Id: __init__.py,v 1.122 2017/09/04 14:56:11 stroeder Exp $
 """
 
 # This is also the overall release version number
 
-__version__ = '2.4.39'
+__version__ = '2.4.43'
 
 import sys
 
