@@ -1,15 +1,16 @@
 # -*- coding: utf-8 -*-
 """
 ldap.controls.pwdpolicy - classes for Password Policy controls
-(see http://tools.ietf.org/html/draft-vchu-ldap-pwd-policy)
+(see https://tools.ietf.org/html/draft-vchu-ldap-pwd-policy)
 
-See http://www.python-ldap.org/ for project details.
+See https://www.python-ldap.org/ for project details.
 
-$Id: pwdpolicy.py,v 1.4 2014/03/12 21:34:07 stroeder Exp $
+$Id: pwdpolicy.py,v 1.6 2017/08/15 16:21:58 stroeder Exp $
 """
 
 __all__ = [
-  'ExpirationWarningControl'
+  'PasswordExpiringControl',
+  'PasswordExpiredControl',
 ]
 
 # Imports from python-ldap 2.4+
