@@ -1,9 +1,9 @@
 """
 ldapobject.py - wraps class _ldap.LDAPObject
 
-See http://www.python-ldap.org/ for details.
+See https://www.python-ldap.org/ for details.
 
-\$Id: ldapobject.py,v 1.162 2017/04/27 08:40:10 stroeder Exp $
+\$Id: ldapobject.py,v 1.165 2017/09/04 14:59:12 stroeder Exp $
 
 Compability:
 - Tested with Python 2.0+ but should work with Python 1.5.x
@@ -112,8 +112,11 @@ class SimpleLDAPObject:
       finally:
         self._ldap_object_lock.release()
     except LDAPError, e:
-      if not e.args[0].has_key('info') and e.args[0].has_key('errno'):
+      try:
+        if not e.args[0].has_key('info') and e.args[0].has_key('errno'):
           e.args[0]['info'] = strerror(e.args[0]['errno'])
+      except IndexError:
+        pass
       if __debug__ and self._trace_level>=2:
         self._trace_file.write('=> LDAPError - %s: %s\n' % (e.__class__.__name__,str(e)))
       raise
@@ -250,13 +253,11 @@ class SimpleLDAPObject:
     """
     Send a SASL bind request using a non-interactive SASL method (e.g. GSSAPI, EXTERNAL)
     """
-    self.sasl_interactive_bind_s(
-      '',
-      ldap.sasl.sasl(
-        {ldap.sasl.CB_USER:authz_id},
-        sasl_mech
-      )
+    auth = ldap.sasl.sasl(
+      {ldap.sasl.CB_USER:authz_id},
+      sasl_mech
     )
+    self.sasl_interactive_bind_s('',auth,serverctrls,clientctrls,sasl_flags)
 
   def sasl_external_bind_s(self,serverctrls=None,clientctrls=None,sasl_flags=ldap.SASL_QUIET,authz_id=''):
     """
