@@ -1,15 +1,15 @@
 """
 ldif - generate and parse LDIF data (see RFC 2849)
 
-See http://www.python-ldap.org/ for details.
+See https://www.python-ldap.org/ for details.
 
-$Id: ldif.py,v 1.112 2017/04/28 20:03:51 stroeder Exp $
+$Id: ldif.py,v 1.117 2017/09/04 14:56:11 stroeder Exp $
 
 Python compability note:
 Tested with Python 2.0+, but should work with Python 1.5.2+.
 """
 
-__version__ = '2.4.39'
+__version__ = '2.4.43'
 
 __all__ = [
   # constants
@@ -40,13 +40,14 @@ dn_regex   = re.compile('^%s$' % dn_pattern)
 ldif_pattern = '^((dn(:|::) %(dn_pattern)s)|(%(attrtype_pattern)s(:|::) .*)$)+' % vars()
 
 MOD_OP_INTEGER = {
-  'add'    :0, # ldap.MOD_REPLACE
-  'delete' :1, # ldap.MOD_DELETE
+  'add':0, # ldap.MOD_ADD
+  'delete':1, # ldap.MOD_DELETE
   'replace':2, # ldap.MOD_REPLACE
+  'increment':3, # ldap.MOD_INCREMENT
 }
 
 MOD_OP_STR = {
-  0:'add',1:'delete',2:'replace'
+  0:'add',1:'delete',2:'replace',3:'increment'
 }
 
 CHANGE_TYPES = ['add','delete','modify','modrdn']
