@@ -2,15 +2,15 @@
 """
 slapdtest - module for spawning test instances of OpenLDAP's slapd server
 
-See http://www.python-ldap.org/ for details.
+See https://www.python-ldap.org/ for details.
 
-$Id: slapdtest.py,v 1.12 2017/05/31 12:35:00 stroeder Exp $
+$Id: slapdtest.py,v 1.20 2017/09/04 14:56:11 stroeder Exp $
 
 Python compability note:
 This module only works with Python 2.7.x since
 """
 
-__version__ = '2.4.39'
+__version__ = '2.4.43'
 
 import os
 import socket
@@ -25,7 +25,7 @@ import urllib
 SLAPD_CONF_TEMPLATE = r"""
 serverID %(serverid)s
 moduleload back_%(database)s
-include "%(schema_include)s"
+include "%(schema_prefix)s/core.schema"
 loglevel %(loglevel)s
 allow bind_v2
 
@@ -83,7 +83,7 @@ class SlapdObject(object):
     Controller class for a slapd instance, OpenLDAP's server.
 
     This class creates a temporary data store for slapd, runs it
-    on a private port, and initialises it with a top-level dc and
+    listening on a private Unix domain socket and TCP port, and initialises it with a top-level entry and
     the root user.
 
     When a reference to an instance of this class is lost, the slapd
@@ -99,13 +99,17 @@ class SlapdObject(object):
     # use SASL/EXTERNAL via LDAPI when invoking OpenLDAP CLI tools
     cli_sasl_external = True
     local_host = '127.0.0.1'
+    testrunsubdirs = (
+        'schema',
+    )
+    openldap_schema_files = (
+        'core.schema',
+    )
 
     TMPDIR = os.environ.get('TMP', os.getcwd())
     SBINDIR = os.environ.get('SBIN', '/usr/sbin')
     BINDIR = os.environ.get('BIN', '/usr/bin')
     SCHEMADIR = os.environ.get('SCHEMA', '/etc/openldap/schema')
-    INIT_SCHEMA_FILE = os.environ.get('SCHEMA_FILE', 'core.schema')
-    INIT_SCHEMA_PATH = os.environ.get('SCHEMA_PATH', os.path.join(SCHEMADIR, INIT_SCHEMA_FILE))
     PATH_LDAPADD = os.path.join(BINDIR, 'ldapadd')
     PATH_LDAPMODIFY = os.path.join(BINDIR, 'ldapmodify')
     PATH_LDAPWHOAMI = os.path.join(BINDIR, 'ldapwhoami')
@@ -121,18 +125,24 @@ class SlapdObject(object):
         self._port = self._avail_tcp_port()
         self.server_id = self._port % 4096
         self.testrundir = os.path.join(self.TMPDIR, 'python-ldap-test-%d' % self._port)
+        self._schema_prefix = os.path.join(self.testrundir, 'schema')
         self._slapd_conf = os.path.join(self.testrundir, 'slapd.conf')
         self._db_directory = os.path.join(self.testrundir, "openldap-data")
         self.ldap_uri = "ldap://%s:%d/" % (LOCALHOST, self._port)
         ldapi_path = os.path.join(self.testrundir, 'ldapi')
         self.ldapi_uri = "ldapi://%s" % urllib.quote_plus(ldapi_path)
 
-    def _setup_rundir(self):
+    def setup_rundir(self):
         """
         creates rundir structure
+
+        for setting up a custom directory structure you have to override
+        this method
         """
         os.mkdir(self.testrundir)
         os.mkdir(self._db_directory)
+        self._create_sub_dirs(self.testrunsubdirs)
+        self._ln_schema_files(self.openldap_schema_files, self.SCHEMADIR)
 
     def _cleanup_rundir(self):
         """
@@ -165,13 +175,16 @@ class SlapdObject(object):
         self._log.info('Found available port %d', port)
         return port
 
-    def _gen_config(self):
+    def gen_config(self):
         """
         generates a slapd.conf and returns it as one string
+
+        for generating specific static configuration files you have to
+        override this method
         """
         config_dict = {
             'serverid': hex(self.server_id),
-            'schema_include': self.INIT_SCHEMA_PATH,
+            'schema_prefix':self._schema_prefix,
             'loglevel': self.slapd_loglevel,
             'database': self.database,
             'directory': self._db_directory,
@@ -183,11 +196,30 @@ class SlapdObject(object):
         }
         return self.slapd_conf_template % config_dict
 
+    def _create_sub_dirs(self, dir_names):
+        """
+        create sub-directories beneath self.testrundir
+        """
+        for dname in dir_names:
+            dir_name = os.path.join(self.testrundir, dname)
+            self._log.debug('Create directory %s', dir_name)
+            os.mkdir(dir_name)
+
+    def _ln_schema_files(self, file_names, source_dir):
+        """
+        write symbolic links to original schema files
+        """
+        for fname in file_names:
+            ln_source = os.path.join(source_dir, fname)
+            ln_target = os.path.join(self._schema_prefix, fname)
+            self._log.debug('Create symlink %s -> %s', ln_source, ln_target)
+            os.symlink(ln_source, ln_target)
+
     def _write_config(self):
         """Writes the slapd.conf file out, and returns the path to it."""
         self._log.debug('Writing config to %s', self._slapd_conf)
         config_file = file(self._slapd_conf, 'wb')
-        config_file.write(self._gen_config())
+        config_file.write(self.gen_config())
         config_file.close()
         self._log.info('Wrote config to %s', self._slapd_conf)
 
@@ -245,7 +277,7 @@ class SlapdObject(object):
         if self._proc is None:
             # prepare directory structure
             self._cleanup_rundir()
-            self._setup_rundir()
+            self.setup_rundir()
             self._write_config()
             self._test_config()
             self._start_slapd()
