@@ -2,9 +2,9 @@
 """
 Automatic tests for python-ldap's module ldap.ldapobject
 
-See http://www.python-ldap.org/ for details.
+See https://www.python-ldap.org/ for details.
 
-$Id: t_ldapobject.py,v 1.7 2017/04/28 07:30:59 stroeder Exp $
+$Id: t_ldapobject.py,v 1.10 2017/09/04 14:59:57 stroeder Exp $
 """
 
 import os
@@ -88,7 +88,7 @@ class Test01_SimpleLDAPObject(SlapdTestCase):
             attrlist=['*'],
         )
         result.sort()
-        self.assertEquals(
+        self.assertEqual(
             result,
             [
                 (
@@ -118,7 +118,7 @@ class Test01_SimpleLDAPObject(SlapdTestCase):
             ['*'],
         )
         result.sort()
-        self.assertEquals(
+        self.assertEqual(
             result,
             [
                 (
@@ -144,7 +144,7 @@ class Test01_SimpleLDAPObject(SlapdTestCase):
             ['cn'],
         )
         result.sort()
-        self.assertEquals(
+        self.assertEqual(
             result,
             [('cn=Foo4,ou=Container,'+self.server.suffix, {'cn': ['Foo4']})]
         )
@@ -175,6 +175,15 @@ class Test01_SimpleLDAPObject(SlapdTestCase):
         else:
             self.fail("expected INVALID_CREDENTIALS, got %r" % r)
 
+    def test_sasl_extenal_bind_s(self):
+        l = self.ldap_object_class(self.server.ldapi_uri)
+        l.sasl_external_bind_s()
+        self.assertEqual(l.whoami_s(), 'dn:'+self.server.root_dn.lower())
+        authz_id = 'dn:cn=Foo2,%s' % (self.server.suffix)
+        l = self.ldap_object_class(self.server.ldapi_uri)
+        l.sasl_external_bind_s(authz_id=authz_id)
+        self.assertEqual(l.whoami_s(), authz_id.lower())
+        
 
 class Test02_ReconnectLDAPObject(Test01_SimpleLDAPObject):
     """
